package org.framework.lazy.cloud.network.heartbeat.common.constant;

import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpClientProxyClientTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpClientProxyServerTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpLocalProxyTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.client.*;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.server.*;
import org.framework.lazy.cloud.network.heartbeat.common.enums.TcpMessageTypeEnums;

/**
 * http代理消息类型
 * 90~120
 * 数据取值范围 -128~ 127
 * 当前约束范围 96~127
 */
public class ProxyMessageType {

    /**
     * http 本地代理
     *
     * @see TcpMessageTypeEnums#HTTP_LOCAL_PROXY
     * @see AbstractHttpLocalProxyTypeAdvanced
     */
    public static final byte HTTP_LOCAL_PROXY = 96;
    /**
     * http 远程客户端代理
     *
     * @see TcpMessageTypeEnums#HTTP_CLIENT_PROXY_CLIENT_
     * @see AbstractHttpClientProxyClientTypeAdvanced
     */
    public static final byte HTTP_CLIENT_PROXY_CLIENT_ = HTTP_LOCAL_PROXY + 1;


    /**
     * http 远程服务端代理
     *
     * @see TcpMessageTypeEnums#HTTP_CLIENT_PROXY_SERVER_
     * @see AbstractHttpClientProxyServerTypeAdvanced
     */
    public static final byte HTTP_CLIENT_PROXY_SERVER_ = HTTP_CLIENT_PROXY_CLIENT_ + 1;
    /**
     * http 远程服务端代理传输数据上报
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_
     * @see AbstractHandleHttpReportClientProxyServerTransferTypeAdvanced
     */
    public static final byte HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_ = HTTP_CLIENT_PROXY_SERVER_ + 1;
    /**
     * http 远程代理服务通道关闭
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_
     * @see AbstractHandleHttpReportClientProxyServerTransferCloseTypeAdvanced
     */
    public static final byte HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_ = HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_ + 1;


    /**
     * http 客户端远程客户端代理传输连接
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_
     * @see AbstractHandleHttpReportClientProxyClientConnectionTransferTypeAdvanced
     */
    public static final byte HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_ = HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_ + 1;


    /**
     * http 目标客户端传输通道连接初始化成功
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_
     * @see AbstractHandleHttpReportClientProxyClientTransferChannelInitSuccessfulTypeAdvanced
     */
    public static final byte HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_ = HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_ + 1;


    /**
     * http 另一个客户端将返回数据通过传输通道返回
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_
     * @see AbstractHandleHttpReportClientProxyClientTransferResponseTypeAdvanced
     */
    public static final byte HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_ = HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_ + 1;

    /**
     * 上报传输通道关闭
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleHttpReportClientProxyClientTransferCloseTypeAdvanced
     */
    public static final byte HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_ = HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_ + 1;

    /**
     * http 服务端代理客户端
     *
     * @see TcpMessageTypeEnums#HTTP_SERVER_PROXY_CLIENT_
     * @see AbstractHttpServerProxyClientTypeAdvanced
     */
    public static final byte HTTP_SERVER_PROXY_CLIENT_ = HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_ + 1;


    /**
     * http 上报客户端连接成功
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_
     * @see AbstractHandleHttpReportServerProxyClientTransferChannelInitSuccessfulTypeAdvanced
     */
    public static final byte HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_ = HTTP_SERVER_PROXY_CLIENT_ + 1;

    /**
     * 下发返回结果
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_
     * @see AbstractHandleHttpReportServerProxyClientTransferResponseTypeAdvanced
     */
    public static final byte HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_ = HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_ + 1;
    /**
     * 上报传输通道关闭
     *
     * @see TcpMessageTypeEnums#HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleHttpReportServerProxyClientTransferCloseTypeAdvanced
     */
    public static final byte HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_ = HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_ + 1;






    public static final byte HTTP_DISTRIBUTE_PROXY = -96;

    /**
     * 下发服务端路由
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_
     * @see AbstractHandleHttpDistributeClientProxyServerServerRouteTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_ = HTTP_DISTRIBUTE_PROXY - 1;


    /**
     * 下发客户端路由
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_
     * @see AbstractHandleHttpDistributeClientProxyServerClientRouteTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_ = HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_ - 1;


    /**
     * http 下发服务端连接客户端
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_SUCCESSFUL_
     * @see AbstractHandleHttpDistributeServerProxyClientConnectionSuccessfulTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_SUCCESSFUL_ = HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_ - 1;

    /**
     * http 下发数据到另一个客户端
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_
     * @see AbstractHandleHttpDistributeServerProxyClientTransferRequestTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_ = HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_SUCCESSFUL_ - 1;


    /**
     * http 远程服务端代理传输数据下发
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_
     * @see AbstractHandleHttpDistributeClientProxyServerTransferTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_ = HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_ - 1;



    /**
     * http 客户端代理客户端，客户端连接服务端成功
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESSFUL_
     * @see AbstractHandleHttpDistributeClientProxyClientConnectionTransferSuccessfulTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESSFUL_ = HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_ - 1;


    /**
     * 下发返回结果
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_
     * @see AbstractHandleHttpDistributeClientProxyClientTransferResponseTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_ = HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESSFUL_ - 1;
    /**
     * 下发传输通道关闭
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleHttpDistributeClientProxyClientTransferCLoseTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_ = HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_ - 1;


    /**
     * http 下发数据到另一个客户端
     *
     * @see TcpMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_
     * @see AbstractHandleHttpDistributeClientProxyClientTransferRequestTypeAdvanced
     */
    public static final byte HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_ = HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_ - 1;


}
